
# Flitter Pygments

[![CI lint](https://github.com/jonathanhogg/flitter-pygments/actions/workflows/ci-lint.yml/badge.svg?)](https://github.com/jonathanhogg/flitter-pygments/actions/workflows/ci-lint.yml)
[![Release package](https://github.com/jonathanhogg/flitter-pygments/actions/workflows/release-package.yml/badge.svg)](https://github.com/jonathanhogg/flitter-pygments/actions/workflows/release-package.yml)

This package provides a [Pygments](https://pygments.org) lexer for the [Flitter
programming language](https://flitter.readthedocs.io/). This enables syntax
highlighting in [Sphinx](https://www.sphinx-doc.org/en/master/) documentation
and anything else that uses Pygments.
